@@ -20,10 +20,10 @@ class Strategy1(FlaskView):
                 self.coin_map[coin.coin_id] = coin
 
     def update_price(self):
-        data = market_api.get_tickers().data
+        data = market_api.get_tickers('SPOT').data
         data_map = dict([(cin['instId'], cin['last']) for cin in data])
         for coin in self.coin_map.values():
-            coin.price = data_map[coin.coin_id]
+            coin.price = float(data_map[coin.coin_id])
 
     def to_json(self):
         return {
@@ -37,3 +37,4 @@ class Strategy1(FlaskView):
         for coin in self.coin_map.values():
             coin.watch()
         return self.to_json()
+
